@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2020 - 2021 TU Wien.
+# Copyright (C) 2020 - 2022 TU Wien.
 #
 # Invenio-Utilities-TUW is free software; you can redistribute it and/or
 # modify it under the terms of the MIT License; see LICENSE file for more
@@ -13,6 +13,7 @@ import click
 from .drafts import drafts
 from .files import files
 from .records import records
+from .search import search
 from .users import users
 
 
@@ -24,4 +25,5 @@ def utilities():
 utilities.add_command(drafts)
 utilities.add_command(files)
 utilities.add_command(records)
+utilities.add_command(search)
 utilities.add_command(users)
